from .. import Provider as CurrencyProvider

# Names taken from https://std.moc.go.th/std/codelist_detail/40


class Provider(CurrencyProvider):
    # Format: (code, name)
    currencies = (
        ("AED", "ดีแรห์ม สหรัฐอาหรับเอมิเรตส์"),
        ("AFN", "อัฟกานิ"),
        ("ALL", "เลค"),
        ("AMD", "ดีแรห์ม อาร์เมเนีย"),
        ("ANG", "กิลเดอร์ เนเธอร์แลนด์แอนทิลลิส"),
        ("AOA", "ควันซา"),
        ("ARS", "เปโซ อาร์เจนตินา"),
        ("AUD", "ดอลลาร์ ออสเตรเลีย"),
        ("AWG", "กิลเดอร์ อารูบา"),
        ("AZN", "มานาท อาเซอร์ไบจาน"),
        ("BAM", "มาร์ค บอสเนียและเฮอร์เซโกวีนา"),
        ("BBD", "ดอลลาร์ บาร์เบโดส"),
        ("BDT", "ตากา"),
        ("BGN", "เลฟ บัลแกเรีย"),
        ("BHD", "ดีนาร์ บาห์เรน"),
        ("BIF", "ฟรังก์ บุรุนดี"),
        ("BMD", "ดอลลาร์ เบอร์มิวดา"),
        ("BND", "ดอลลาร์ บรูไนดารุสซาลาม"),
        ("BOB", "โบลีเวียโน"),
        ("BRL", "เรียล บราซิล"),
        ("BSD", "ดอลลาร์ บาฮามาส"),
        ("BTN", "เองกัลทรัม"),
        ("BWP", "พูลา"),
        ("BYR", "รูเบิล เบลารุส"),
        ("BZD", "ดอลลาร์ เบลีซ"),
        ("CAD", "ดอลลาร์ แคนาดา"),
        ("CDF", "ฟรังก์ คองโก"),
        ("CHF", "ฟรังก์ สวิส"),
        ("CLF", "ฟันด์ โค้ด ยูนิแดด ดี โฟเมนโต"),
        ("CLP", "เปโซ ชิลี"),
        ("CNY", "หยวนเหรินหมินปี้"),
        ("COP", "เปโซ โคลอมเบีย"),
        ("COU", "ยูนิแดด ดี วาโล เรียล"),
        ("CRC", "โคโลน คอสตาริกา"),
        ("CUC", "แปลงสภาพเปโซ"),
        ("CUP", "เปโซ คิวบา"),
        ("CVE", "เอสคูโด เคปเวิร์ด"),
        ("CZK", "คราวน์ เช็ก"),
        ("DJF", "ฟรังก์ จิบูตี"),
        ("DKK", "โครน เดนมาร์ก"),
        ("DOP", "เปโซ สาธารณรัฐโดมินิกัน"),
        ("DZD", "ดีนาร์ แอลจีเรีย"),
        ("EGP", "ปอนด์ อียิปต์"),
        ("ERN", "นาคฟา"),
        ("ETB", "เปอร์ เอธิโอเปีย"),
        ("EUR", "ยูโร"),
        ("FJD", "ดอลลาร์ ฟิจิ"),
        ("FKP", "ปอนด์ หมู่เกาะฟอล์กแลนด์"),
        ("GBP", "ปอนด์สเตอลิง"),
        ("GEL", "ลารี"),
        ("GHS", "เซดี กานา"),
        ("GIP", "ปอนด์ ยิบรอลตาร์"),
        ("GMD", "ดาราซี"),
        ("GNF", "ฟรังก์ กินี"),
        ("GTQ", "เก็ตซาล"),
        ("GYD", "ดอลลาร์ กายอานา"),
        ("HKD", "ดอลลาร์ ฮ่องกง"),
        ("HNL", "เลมพีรา ฮอนดูรัส"),
        ("HRK", "คูนา"),
        ("HTG", "กอร์ด"),
        ("HUF", "ฟอรินท์"),
        ("IDR", "รูเปีย"),
        ("ILS", "เชคเกิล อิสราเอล"),
        ("INR", "รูปี อินเดีย"),
        ("IQD", "ดีนาร์ อิรัก"),
        ("IRR", "เรียล อิหร่าน"),
        ("ISK", "โครนา ไอซ์แลนด์"),
        ("JMD", "ดอลลาร์ จาเมกา"),
        ("JOD", "ดอลลาร์ จอร์แดน"),
        ("JPY", "เยน"),
        ("KES", "ชิลลิง เคนยา"),
        ("KGS", "ซอม"),
        ("KHR", "เรียล กัมพูชา"),
        ("KMF", "ฟรังก์ คอโมโรส"),
        ("KPW", "วอน เกาหลีเหนือ"),
        ("KRW", "วอน เกาหลีใต้"),
        ("KWD", "ดีนาร์ คูเวต"),
        ("KYD", "ดอลลาร์ หมู่เกาะเคย์แมน"),
        ("KZT", "เทงเก"),
        ("LAK", "กีบ"),
        ("LBP", "ปอนด์ เลบานอน"),
        ("LKR", "รูปี ศรีลังกา"),
        ("LRD", "ดอลลาร์ ไลบีเรีย"),
        ("LSL", "โลตี"),
        ("LTL", "ลีทาส ลิทัวเนีย"),
        ("LVL", "ลัตส์ ลัตเวีย"),
        ("LYD", "ดีนาร์ ลิเบีย"),
        ("MAD", "ดีแรห์ม โมร็อกโก"),
        ("MDL", "ลิว มอลโดวา"),
        ("MGA", "อเรียรี่ มาดากัสการ์"),
        ("MKD", "ดีนาร์ มาซิโดเนีย"),
        ("MMK", "จัต"),
        ("MNT", "ทูกริค"),
        ("MOP", "พาทากา"),
        ("MRO", "อูกุยยา / อูกียา"),
        ("MUR", "รูปี มอริเชียส"),
        ("MVR", "รูฟียา"),
        ("MWK", "ควาซา มาลาวี"),
        ("MXN", "เปโซ เม็กซิโก"),
        ("MYR", "ริงกิต มาเลเซีย"),
        ("MZN", "เมททิคัล โมซัมบิก"),
        ("NAD", "ดอลลาร์ นามิเบีย"),
        ("NGN", "ไนรา"),
        ("NIO", "คอร์โดบา"),
        ("NOK", "โครน นอร์เวย์"),
        ("NPR", "รูปี เนปาล"),
        ("NZD", "ดอลลาร์ นิวซีแลนด์"),
        ("OMR", "เรียล โอมาน"),
        ("PAB", "บัลโบอา"),
        ("PEN", "ซัล เปรู"),
        ("PGK", "คีนา"),
        ("PHP", "เปโซ ฟิลิปปินส์"),
        ("PKR", "รูปี ปากีสถาน"),
        ("PLN", "สล็อตตี"),
        ("PYG", "กวารานี"),
        ("QAR", "เรียล กาตาร์"),
        ("RON", "ลิว โรมาเนีย"),
        ("RSD", "ดีนาร์ เซอร์เบีย"),
        ("RUB", "รูเบิล รัสเซีย"),
        ("RWF", "ฟรังก์ รวันดา"),
        ("SAR", "ริยัล ซาอุดีอาระเบีย"),
        ("SBD", "ดอลลาร์ หมู่เกาะโซโลมอน"),
        ("SCR", "รูปี เซเชลส์"),
        ("SDG", "ปอนด์ ซูดาน"),
        ("SEK", "โครนา สวีเดน"),
        ("SGD", "ดอลลาร์ สิงคโปร์"),
        ("SHP", "ปอนด์ เซนต์เฮเลนา"),
        ("SLL", "ลีโอน"),
        ("SOS", "ชิลลิง โซมาเลีย"),
        ("SRD", "ดอลลาร์ ซูรินาเม"),
        ("SSP", "ปอนด์ เซาท์ซูดาน"),
        ("STD", "โดบรา"),
        ("SVC", "โคโลน เอลซัลวาดอร์"),
        ("SYP", "ปอนด์ ซีเรีย"),
        ("SZL", "ลิลอนเกนี"),
        ("THB", "บาท"),
        ("TJS", "โซโมนิ"),
        ("TMT", "มานาท เติร์กเมนิสถานใหม่"),
        ("TND", "ดีนาร์ ตูนิเซีย"),
        ("TOP", "พาอานกา"),
        ("TRY", "ลีร์ ตุรกี"),
        ("TTD", "ดอลลาร์ ตรินิแดดและโตเบโก"),
        ("TWD", "ดอลลาร์ ไต้หวัน"),
        ("TZS", "ชิลลิง แทนซาเนีย"),
        ("UAH", "รีฟเนีย"),
        ("UGX", "ชิลลิง ยูกันดา"),
        ("USD", "ดอลลาร์ สหรัฐอเมริกา"),
        ("USN", "ดอลลาร์ สหรัฐอเมริกา เน็กซ์เดย์ฟัน"),
        ("UYI", "อุรุกวัย เปโซ เอ็น อุนดิดาเดซ อินเด็กซาดาซ"),
        ("UYU", "เปโซ อุรุกวัย"),
        ("UZS", "โซม อุซเบกิสถาน"),
        ("VEF", "โบลิวาร์"),
        ("VND", "ดอง"),
        ("VUV", "วาตู"),
        ("WST", "ทาลา"),
        ("XAF", "ฟรังก์ ซีเอฟเอ บีอีเอซี"),
        ("XAG", "เงิน"),
        ("XAU", "ทองคำ"),
        ("XBA", "อียูอาร์ซีโอ"),
        ("XBB", "อีเอ็มยู 6"),
        ("XBC", "บัญชี อียู 9"),
        ("XBD", "บัญชี อียู 17"),
        ("XCD", "ดอลลาร์ คาริบเบียลตะวันออก"),
        ("XDR", "สิทธิพิเศษถอนเงิน (กองทุนการเงินระหว่างประเทศ)"),
        ("XEU", "อี ซี ยู"),
        ("XFU", "ยูไอซี ฟรังก์"),
        ("XOF", "ฟรังก์ ซีเอฟเอ บีซีอีเอโอ"),
        ("XPD", "พัลเลเดียม"),
        ("XPF", "ฟรังก์ ซีเอฟพี"),
        ("XPT", "แพลตตินัม"),
        ("XSU", "ซูเคร"),
        ("XUA", "เอดีบี"),
        ("XXX", "ธุรกรรมที่ไม่มีเงินสกุลใดเกี่ยวข้อง"),
        ("YER", "เรียล เยเมน"),
        ("ZAR", "แรนด์"),
        ("ZMW", "ควาซา แซมเบีย"),
        ("ZWL", "ดอลลาร์ ซิมบับเว"),
    )
