from .. import Provider as BaseProvider


class Provider(BaseProvider):
    # Source: https://learnenglish100.com/grammar/career-job/
    jobs = (
        "محاسب",
        "ممثل",
        "ممثلة",
        "محام",
        "مضيفة في الطائرة",
        "مضيفة جوية",
        "عالم",
        "عالم اثار",
        "فنان",
        "مؤلف",
        "خباز",
        "راقصة باليه",
        "مدير بنك",
        "حلاق",
        "أحيائي",
        "حداد",
        "مجلد كتب",
        "صاحب مكتبة",
        "نباتي",
        "عامل بناء",
        "جزار",
        "مشتري",
        "نجار",
        "رئيس طهاه",
        "صيدلي",
        "قائد شرطة",
        "موظف حكومي",
        "كاتب",
        "ملحن",
        "طباخ",
        "مصحح قانوني",
        "راقصة",
        "مصمم ديكور",
        "موصل طلبيات",
        "طبيب أسنان",
        "مصصم",
        "رجل مباحث",
        "مدير او مخرج",
        "طبيب",
        "رسام",
        "خياطة",
        "سائق",
        "صباغ",
        "خبير اقتصادي",
        "محرر",
        "محرر جريدة",
        "مھندس",
        "خبير في التراث الشعبي",
        "منسق ازياء",
        "اطفائي",
        "بائع زهور",
        "جيولوجي",
        "صائغ",
        "مصمم جرافيك",
        "بائع خضار وفاكهة",
        "حلاق",
        "مصفف شعر",
        "مصور",
        "وسيط تأمين",
        "مترجم",
        "مكوى",
        "بواب",
        "جوھري",
        "صحافي",
        "قاضي",
        "غسالة",
        "محام",
        "محاضر",
        "لغوي",
        "سائق شاحنة",
        "خادمة",
        "ساعي بريد",
        "مدير",
        "مدير تسويق",
        "عالم رياضيات",
        "ميكانيكي",
        "تاجر",
        "عالم أرصاد جوية",
        "داية",
        "عارضة أزياء",
        "صراف",
        "موسيقار",
        "مذيع",
        "موزع جرائد",
        "روائي",
        "ممرضة",
        "طبيب عيون",
        "صانع أدوات بصرية",
        "رسام",
        "مدير موظفين",
        "صيدلي",
        "فيلسوف",
        "مصور",
        "عالم فيزياء",
        "معالج طبيعي",
        "طيار",
        "كاتب مسرحي",
        "سمكري",
        "شاعر",
        "ضابط شرطة",
        "شرطي",
        "سياسي",
        "صاحب مطبعة",
        "منتج",
        "مبرمج",
        "طبيب نفساني",
        "ناشر",
        "وكيل عقارات",
        "موظف استقبال",
        "صحفي",
        "مساعد مبيعات",
        "بائع",
        "بائعة",
        "عالم",
        "نحات",
        "سكرتير",
        "سكرتيرة",
        "صباغ أحذية",
        "عامل أحذية",
        "ماسح احذية",
        "عامل بمتجر",
        "صاحب متجر",
        "مطرب",
        "مغني",
        "احصائي",
        "مدير متجر",
        "طبيب جراح",
        "خياط",
        "سائق تاكسي",
        "معلم",
        "موظف بدالة",
        "مترجم",
        "وكيل سفر",
        "سائق شاحنة",
        "خراط",
        "ضارب على الآلة الكاتبة",
        "منجد",
        "نادلة",
        "ساعاتي",
        "عامل",
        "كاتب",
        "خبير في عالم الحيوان",
    )
