from .. import Provider as LoremProvider


class Provider(LoremProvider):
    """Implement lorem provider for ``ar_AA`` locale."""

    word_list = (
        "تاريخ",
        "ثمّة",
        "ويكيبيديا",
        "واشتدّت",
        "عن",
        "أوروبا",
        "التغييرات",
        "كثيرة",
        "سنغافورة",
        "اللازمة",
        "جُل",
        "قد",
        "أن",
        "الشّعبين",
        "للجزر",
        "بالشرقي",
        "ذات",
        "والتي",
        "نهاية",
        "عرفها",
        "وسفن",
        "وبولندا",
        "بالمطالبة",
        "وقوعها",
        "معاملة",
        "العصبة",
        "لمّ",
        "البرية",
        "بعدم",
        "واُسدل",
        "حالية",
        "فمرّ",
        "قبضتهم",
        "وإقامة",
        "الأعمال",
        "معارضة",
        "الإمتعاض",
        "٢٠٠٤",
        "كانت",
        "بينما",
        "شعار",
        "وتزويده",
        "معقل",
        "عشوائية",
        "مدينة",
        "وفي",
        "الأوروبيّون",
        "فكان",
        "ضرب",
        "سكان",
        "الأوروبية",
        "الأمريكي",
        "وبغطاء",
        "الربيع",
        "المضي",
        "جدول",
        "التقليدية",
        "العاصمة",
        "التنازلي",
        "إبّان",
        "بها",
        "الجنوبي",
        "وتنامت",
        "استدعى",
        "الرئيسية",
        "بالتوقيع",
        "بداية",
        "دخول",
        "أثره",
        "الدنمارك",
        "واقتصار",
        "الساحل",
        "الوزراء",
        "الثالث",
        "تونس",
        "الخاسرة",
        "الحيلولة",
        "لفشل",
        "الإطلاق",
        "ماذا",
        "مواقعها",
        "الجديدة",
        "والنفيس",
        "الأرواح",
        "أكثر",
        "الأوربيين",
        "والفرنسي",
        "أوزار",
        "بلديهما",
        "وايرلندا",
        "يتم",
        "جعل",
        "عرض",
        "أفريقيا",
        "إستعمل",
        "التقليدي",
        "عُقر",
        "طوكيو",
        "اتفاقية",
        "بمحاولة",
        "اوروبا",
        "منتصف",
        "أسر",
        "بالرّغم",
        "بضرب",
        "إحكام",
        "أجزاء",
        "الخارجية",
        "كنقطة",
        "بشرية",
        "بقادة",
        "لبلجيكا",
        "استطاعوا",
        "بسبب",
        "تسمّى",
        "الحرة",
        "يرتبط",
        "شاسعة",
        "الواقعة",
        "مارد",
        "والمعدات",
        "لمحاكم",
        "بعلى",
        "التبرعات",
        "ضمنها",
        "فعل",
        "٣٠",
        "الاندونيسية",
        "الى",
        "مكثّفة",
        "وقدّموا",
        "الأثنان",
        "أخرى",
        "العالمي",
        "واحدة",
        "وترك",
        "الحكم",
        "بهناك",
        "بأيدي",
        "باستخدام",
        "الذود",
        "ولكسمبورغ",
        "بعشوائية",
        "الأوضاع",
        "رجوعهم",
        "وأزيز",
        "سياسة",
        "ليبين",
        "رئيس",
        "الجوي",
        "سقطت",
        "تكاليف",
        "وكسبت",
        "وعلى",
        "احداث",
        "شموليةً",
        "إيطاليا",
        "عجّل",
        "أحكم",
        "الدمج",
        "محاولات",
        "يعادل",
        "بريطانيا-فرنسا",
        "ديسمبر",
        "قتيل",
        "التاريخ",
        "استبدال",
        "مقاومة",
        "السيء",
        "الصعداء",
        "أعمال",
        "مسارح",
        "ومضى",
        "تعد",
        "صفحة",
        "النفط",
        "وهولندا",
        "وبريطانيا",
        "جهة",
        "بين",
        "اتّجة",
        "واعتلاء",
        "ومحاولة",
        "المارق",
        "المؤلّفة",
        "شمال",
        "لهذه",
        "بحث",
        "وانهاء",
        "غريمه",
        "وبحلول",
        "وقبل",
        "بتصفح",
        "بال",
        "الفرنسي",
        "وسمّيت",
        "ترتيب",
        "واستمرت",
        "ببلا",
        "الدولارات",
        "إعمار",
        "إعادة",
        "به",
        "الضغوط",
        "حصدت",
        "بقسوة",
        "الطريق",
        "وانتهاءً",
        "حول",
        "اكتوبر",
        "الخاسر",
        "ايطاليا",
        "للأراضي",
        "عالمية",
        "جديدة",
        "أخر",
        "غينيا",
        "قُدُماً",
        "و",
        "مسؤولية",
        "ابتدعها",
        "أمّا",
        "الأول",
        "أدوات",
        "يطول",
        "تُصب",
        "الأولى",
        "المسرح",
        "بهيئة",
        "الخطّة",
        "موالية",
        "مليون",
        "بالجانب",
        "إيو",
        "الهجوم",
        "أعلنت",
        "المدن",
        "علاقة",
        "باستحداث",
        "انتباه",
        "بالولايات",
        "مدن",
        "أساسي",
        "لفرنسا",
        "الجنوب",
        "الثقيل",
        "والعتاد",
        "بقعة",
        "العدّ",
        "اتفاق",
        "تحت",
        "الإحتفاظ",
        "بوقامت",
        "التي",
        "ب٠٨٠٤",
        "ولاتّساع",
        "الا",
        "حكومة",
        "مما",
        "بحيث",
        "مليارات",
        "شواطيء",
        "التحالف",
        "الأوروبي",
        "قام",
        "يتعلّق",
        "مايو",
        "هاربر",
        "العمليات",
        "أما",
        "يعبأ",
        "وشعار",
        "الإقتصادية",
        "والكساد",
        "ليرتفع",
        "وبالرغم",
        "قِبل",
        "الله",
        "تكتيكاً",
        "اعتداء",
        "ب٣٠",
        "تسبب",
        "للحكومة",
        "الأهداف",
        "اللا",
        "ببعض",
        "الستار",
        "وبلجيكا",
        "وفنلندا",
        "ميناء",
        "الساحلية",
        "مقاطعة",
        "وتم",
        "السيطرة",
        "تغييرات",
        "ووصف",
        "الجنود",
        "بلمّ",
        "لدحر",
        "بالحرب",
        "كُلفة",
        "وبدون",
        "وصل",
        "أفاق",
        "الأبرياء",
        "مهمّات",
        "العظمى",
        "والقرى",
        "وأكثرها",
        "لان",
        "مشارف",
        "مساعدة",
        "أضف",
        "مشروط",
        "الكونجرس",
        "للصين",
        "الشمل",
        "اليميني",
        "فكانت",
        "سقوط",
        "بتحت",
        "بكلا",
        "تصرّف",
        "الأثناء",
        "بولندا",
        "واندونيسيا",
        "كلّ",
        "إحتار",
        "الخاطفة",
        "كردة",
        "وحلفاؤها",
        "إتفاقية",
        "وبداية",
        "يذكر",
        "حادثة",
        "مئات",
        "الأسيوي",
        "غير",
        "الانجليزية",
        "استعملت",
        "استمرار",
        "المحيط",
        "وصافرات",
        "وحتّى",
        "الخاصّة",
        "وزارة",
        "بحق",
        "بدارت",
        "ماليزيا",
        "جزيرتي",
        "اليابان",
        "هامش",
        "بوابة",
        "وجهان",
        "وقرى",
        "تجهيز",
        "بولم",
        "البولندي",
        "الجو",
        "لكل",
        "فرنسية",
        "تحرّكت",
        "يقوم",
        "ولم",
        "للإتحاد",
        "الغالي",
        "المشترك",
        "التكاليف",
        "بولاتّساع",
        "الفرنسية",
        "بتحدّي",
        "غرّة",
        "الأرض",
        "مشاركة",
        "فصل",
        "بأم",
        "والكوري",
        "وقد",
        "بـ",
        "كل",
        "بزمام",
        "أي",
        "ماشاء",
        "لغات",
        "اليابانية",
        "ونتج",
        "الضروري",
        "مع",
        "عقبت",
        "لليابان",
        "مسرح",
        "فقامت",
        "بتطويق",
        "بتخصيص",
        "الوراء",
        "تعداد",
        "فبعد",
        "تشكيل",
        "الموسوعة",
        "لكون",
        "واستمر",
        "الأمريكية",
        "إجلاء",
        "بدون",
        "قررت",
        "الشتاء",
        "يتمكن",
        "التخطيط",
        "مكن",
        "بريطانيا",
        "أحدث",
        "تشيكوسلوفاكيا",
        "وبدأت",
        "الشهيرة",
        "حدى",
        "الإيطالية",
        "يتسنّى",
        "اقتصادية",
        "التجارية",
        "بشكل",
        "عسكرياً",
        "على",
        "ألمّ",
        "لبولندا",
        "وسوء",
        "جنوب",
        "بالشتاء",
        "الفترة",
        "للمجهود",
        "أسيا",
        "ارتكبها",
        "بلها",
        "قامت",
        "أوراقهم",
        "بجسيمة",
        "بإعمار",
        "وتتحمّل",
        "القوى",
        "قبل",
        "دنو",
        "عدم",
        "دار",
        "الهادي",
        "خطّة",
        "المجتمع",
        "أملاً",
        "دفّة",
        "بخطوط",
        "السفن",
        "لعدم",
        "حاملات",
        "بل",
        "الإتفاقية",
        "الأمور",
        "بانه",
        "مرجع",
        "النزاع",
        "الدّفاع",
        "بكلّ",
        "ان",
        "السبب",
        "المشتّتون",
        "ودول",
        "ألمانيا",
        "والروسية",
        "والفلبين",
        "بلا",
        "أواخر",
        "ببه",
        "تزامناً",
        "أطراف",
        "يونيو",
        "الأراضي",
        "كانتا",
        "ويعزى",
        "انتهت",
        "بالثالث",
        "وباستثناء",
        "زهاء",
        "الآخر",
        "أخذ",
        "ليركز",
        "يتبقّ",
        "تمهيد",
        "الإقتصادي",
        "بالرغم",
        "سبتمبر",
        "بقد",
        "واتّجه",
        "وصغار",
        "الشتوية",
        "سابق",
        "بعض",
        "الشرق",
        "المتساقطة",
        "الصين",
        "اسبوعين",
        "لهيمنة",
        "الصفحات",
        "أم",
        "الساحة",
        "القادة",
        "لعملة",
        "أمام",
        "تحرير",
        "عليها",
        "وحرمان",
        "حلّت",
        "بأضرار",
        "الثقيلة",
        "وجزر",
        "الأرضية",
        "أراض",
        "والحزب",
        "وباءت",
        "حقول",
        "وبالتحديد",
        "لإنعدام",
        "اعلان",
        "خلاف",
        "انه",
        "بتونس",
        "بمما",
        "الأجل",
        "أوسع",
        "الآلاف",
        "تطوير",
        "اليها",
        "البشريةً",
        "والإتحاد",
        "إختار",
        "وبعض",
        "بالمحور",
        "غضون",
        "شرسة",
        "السادس",
        "الإثنان",
        "لتقليعة",
        "الجنرال",
        "تصفح",
        "ثانية",
        "العناد",
        "لم",
        "لإعادة",
        "سليمان",
        "هناك",
        "جمعت",
        "الباهضة",
        "وبعدما",
        "في",
        "تنفّس",
        "ويتّفق",
        "قدما",
        "المنتصر",
        "جيوب",
        "انتصارهم",
        "قادة",
        "تحرّك",
        "الإمداد",
        "الصينية",
        "جسيمة",
        "تكبّد",
        "وعُرفت",
        "استرجاع",
        "فشكّل",
        "دول",
        "فقد",
        "الطرفين",
        "بالرّد",
        "المعاهدات",
        "الأخذ",
        "لإعلان",
        "كرسي",
        "كلا",
        "هذا",
        "الإنذار",
        "عملية",
        "شيء",
        "ومن",
        "جيما",
        "الشرقية",
        "بالعمل",
        "ما",
        "الولايات",
        "حاول",
        "جديداً",
        "حين",
        "العالم",
        "بنقطة",
        "خيار",
        "بالجوي",
        "والديون",
        "بقيادة",
        "بيكن",
        "يبق",
        "ومطالبة",
        "أراضي",
        "حتى",
        "بأراضي",
        "معزّزة",
        "الثانية",
        "دون",
        "بالسيطرة",
        "نتيجة",
        "دارت",
        "بالإنزال",
        "أمدها",
        "الشهير",
        "من",
        "بلاده",
        "تم",
        "الصفحة",
        "ساعة",
        "الإكتفاء",
        "يكن",
        "عل",
        "أصقاع",
        "بالأجل",
        "تلك",
        "إذ",
        "الإتحاد",
        "المتحدة",
        "إستيلاء",
        "بعرض",
        "بفصل",
        "ممثّلة",
        "شدّت",
        "كان",
        "هنا؟",
        "المبرمة",
        "انذار",
        "تعديل",
        "ليتسنّى",
        "وتنصيب",
        "قائمة",
        "الإنزال",
        "إعلان",
        "للسيطرة",
        "بعد",
        "بالسادس",
        "العالمية",
        "ببحشد",
        "بحشد",
        "إنطلاق",
        "والنرويج",
        "هُزم",
        "فاتّبع",
        "لها",
        "بأسر",
        "الشرقي",
        "المواد",
        "الشمال",
        "الأحمر",
        "٠٨٠٤",
        "ثم",
        "نفس",
        "وقام",
        "عدد",
        "أسابيع",
        "هو",
        "كما",
        "وحتى",
        "المتاخمة",
        "أهّل",
        "أدنى",
        "بفرض",
        "وبعد",
        "المتّبعة",
        "بقصف",
        "الدول",
        "لأداء",
        "جورج",
        "وفرنسا",
        "فرنسا",
        "هذه",
        "الحدود",
        "الشطر",
        "نقطة",
        "بدول",
        "فهرست",
        "حيث",
        "استراليا",
        "وإيطالي",
        "دأبوا",
        "الحكومة",
        "الأمم",
        "فسقط",
        "مرمى",
        "ذلك",
        "مكّن",
        "وإعلان",
        "بمباركة",
        "والمانيا",
    )
